﻿using System;
using System.Collections.Generic;
using Infragistics;
using UIKit;

namespace GridResizingAdornerCS
{
	public partial class ViewController : UIViewController
	{
		IGGridView _gridView;
		IGGridViewDataSourceHelper _ds;
		IGGridViewLightTheme _theme;

		protected ViewController(IntPtr handle) : base(handle)
		{
		}

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			this.View.BackgroundColor = UIColor.White;

			List<IGSalesmanItem> data = IGSalesmanItem.GenerateData(100);

			_gridView = new IGGridView(this.View.Bounds, IGGridViewStyle.IGGridViewStyleDefault);
			_gridView.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;
			_gridView.SelectionType = IGGridViewSelectionType.IGGridViewSelectionTypeNone;

			_gridView.Theme = _theme = new IGGridViewLightTheme();

			this.View.AddSubview(_gridView);

			IGGridViewDataSourceHelper ds = new IGGridViewDataSourceHelper();

			if (UIDevice.CurrentDevice.Model.ToLower().Contains("iphone"))
			{
				_gridView.ColumnWidth = IGColumnWidth.CreateNumericColumnWidth(90, 50);
			}
			else
			{
				_gridView.ColumnWidth = IGColumnWidth.CreateNumericColumnWidth(150, 50);
			}

			ds.Data = data.ToArray();
			_ds = ds;

			UIColor bg = UIColor.White;
			foreach (IGGridViewColumnDefinition column in ds.Columns)
			{
				column.BackgroundColor = bg;
				bg = bg.IsEqual(UIColor.White) ? UIColor.LightGray : UIColor.White;
			}

			_gridView.DataSource = ds;
			_gridView.ColumnResizing = IGGridViewColumnResizeAction.IGGridViewColumnResizeActionAdorner;
			AdjustColumnHeaders();
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
		}

		public void AdjustColumnHeaders()
		{
			object[] names = new object[] { "First Name", "Last Name", "Territory", "Sales" };
			for (int i = 0; i < names.Length; i++)
			{
				IGGridViewColumnDefinition col = _ds.Columns.GetValue(i) as IGGridViewColumnDefinition;
				col.HeaderText = names[i] as String;
			}
		}

		public override bool PrefersStatusBarHidden()
		{
			return true;
		}
	}
}

